import os

from base_client import BaseClient
from utils import is_invalid_api_key


class OrquestaIncorrectAPIException(BaseException):
    pass


class OrquestaClient(BaseClient):
    def __init__(self, api_key):
        """
        Construct the Orquesta API object.
        Note that the underlying client is set up during initialization,
        therefore changing attributes will not change client behavior.

        :param api_key: Orquesta workspace API key to use. If not provided, value
                        will be read from environment variable "ORQUESTA_API_KEY".
        :type api_key: string
        :param ttl: Time to live for the rules in the cache. Default = 3600 seconds.
        :type ttl: int
        """
        self.api_key = api_key or os.environ.get("ORQUESTA_API_KEY")

        if not self.api_key or is_invalid_api_key(self.api_key):
            raise OrquestaIncorrectAPIException("API key is not valid")

        auth = "Bearer {}".format(self.api_key)
        super(OrquestaClient, self).__init__(auth)



import requests


class BaseClient(object):
    def __init__(self, token, ttl):
        from version import __version__

        self.token = token
        self.ttl = ttl
        self.version = __version__

    @property
    def headers(self):
        return {
            "Authorization": "{}".format(self.token),
            "Content-Type": "application/json",
            "Accept": "application/json",
            "User-Agent": "orquestadev/{};python".format(self.version),
        }

    def query(self, rule_key, default_value, context={}):

        try:
            response = self._perform_request({"rule_key": rule_key, "context": context})

            result = response.json()

            print(result)

            if result.get("status_code", None) is not None:
                return default_value

            return result[rule_key]

        except requests.exceptions.HTTPError as e:
            return default_value

    def _perform_request(self, data):
        return requests.post(
            "http://api.orquesta.dev/evaluate/", headers=self.headers, json=data
        )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['orquesta_sdk']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.28.2,<3.0.0']

setup_kwargs = {
    'name': 'orquesta-sdk',
    'version': '1.3',
    'description': 'No-code business rules and remote configurations',
    'long_description': 'None',
    'author': 'Orquesta',
    'author_email': 'info@orquesta.dev',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0.0',
}


setup(**setup_kwargs)
